@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2014 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2015 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -15,7 +15,7 @@
 #ifndef ADHOC_H__
 #define ADHOC_H__
 
-#include "dataform.h"
+#include "adhocplugin.h"
 #include "disco.h"
 #include "disconodehandler.h"
 #include "discohandler.h"
@@ -76,7 +76,7 @@ namespace gloox
    * ...TBC...
    *
    * XEP version: 1.2
-   * @author Jakob Schroeter <js@camaya.net>
+   * @author Jakob Schröter <js@camaya.net>
    */
   class GLOOX_API Adhoc : public DiscoNodeHandler, public DiscoHandler, public IqHandler
   {
@@ -85,7 +85,7 @@ namespace gloox
        * @brief An abstraction of an Adhoc Command element (from Adhoc Commands, @xep{0050})
        * as a StanzaExtension.
        *
-       * @author Jakob Schroeter <js@camaya.net>
+       * @author Jakob Schröter <js@camaya.net>
        * @since 1.0
        */
       class GLOOX_API Command : public StanzaExtension
@@ -124,7 +124,7 @@ namespace gloox
           /**
            * An abstraction of a command note.
            *
-           * @author Jakob Schroeter <js@camaya.net>
+           * @author Jakob Schröter <js@camaya.net>
            * @since 1.0
            */
           class GLOOX_API Note
@@ -204,11 +204,11 @@ namespace gloox
            * @param node The node (command) to perform the action on.
            * @param sessionid The session ID of an already running adhoc command session.
            * @param action The action to perform.
-           * @param form An optional DataForm to include in the request. Will be deleted in Command's
+           * @param plugin An optional AdhocPlugin (e.g. DataForm) to include in the request. Will be deleted in Command's
            * destructor.
            */
           Command( const std::string& node, const std::string& sessionid, Action action,
-                   DataForm* form = 0 );
+                   AdhocPlugin* plugin = 0 );
 
           /**
            * Creates a Command object that can be used to perform the provided Action.
@@ -216,11 +216,11 @@ namespace gloox
            * @param node The node (command) to perform the action on.
            * @param sessionid The (possibly newly created) session ID of the adhoc command session.
            * @param status The execution status.
-           * @param form An optional DataForm to include in the reply. Will be deleted in Command's
+           * @param plugin An optional AdhocPlugin (e.g. DataForm) to include in the reply. Will be deleted in Command's
            * destructor.
            */
           Command( const std::string& node, const std::string& sessionid, Status status,
-                   DataForm* form = 0 );
+                   AdhocPlugin* plugin = 0 );
 
           /**
            * Creates a Command object that can be used to perform the provided Action.
@@ -231,12 +231,12 @@ namespace gloox
            * @param status The execution status.
            * @param executeAction The action to execute.
            * @param allowedActions Allowed reply actions.
-           * @param form An optional DataForm to include in the reply. Will be deleted in Command's
+           * @param plugin An optional AdhocPlugin (e.g. DataForm) to include in the reply. Will be deleted in Command's
            * destructor.
            */
           Command( const std::string& node, const std::string& sessionid, Status status,
                    Action executeAction, int allowedActions = Complete,
-                   DataForm* form = 0 );
+                   AdhocPlugin* plugin = 0 );
 
           /**
            * Creates a Command object that can be used to perform the provided Action.
@@ -244,11 +244,11 @@ namespace gloox
            * (single or multi stage).
            * @param node The node (command) to perform the action on.
            * @param action The action to perform.
-           * @param form An optional DataForm to include in the request. Will be deleted in Command's
+           * @param plugin An optional AdhocPlugin (e.g. DataForm) to include in the request. Will be deleted in Command's
            * destructor.
            */
           Command( const std::string& node, Action action,
-                   DataForm* form = 0 );
+                   AdhocPlugin* plugin = 0 );
 
           /**
            * Creates a Command object from the given Tag.
@@ -307,10 +307,17 @@ namespace gloox
           void addNote( const Note* note ) { m_notes.push_back( note ); }
 
           /**
-           * Returns the command's embedded DataForm.
-           * @return The command's embedded DataForm. May be 0.
+           * Returns the command's embedded AdhocPlugin (e.g. DataForm).
+           * @return The command's embedded AdhocPlugin (e.g. DataForm). May be 0.
+           * @note This will be removed in 1.1. Use plugin() instead.
            */
-          const DataForm* form() const { return m_form; }
+          GLOOX_DEPRECATED const AdhocPlugin* form() const { return m_plugin; }
+
+          /**
+           * Returns the command's embedded AdhocPlugin (e.g. DataForm).
+           * @return The command's embedded AdhocPlugin (e.g. DataForm). May be 0.
+           */
+          const AdhocPlugin* plugin() const { return m_plugin; }
 
           // reimplemented from StanzaExtension
           virtual const std::string& filterString() const;
@@ -335,7 +342,7 @@ namespace gloox
 
             c->m_node = m_node;
             c->m_sessionid = m_sessionid;
-            c->m_form = m_form ? static_cast<DataForm*>( m_form->clone() ) : 0;
+            c->m_plugin = m_plugin ? static_cast<AdhocPlugin*>( m_plugin->clone() ) : 0;
             c->m_action = m_action;
             c->m_status = m_status;
             c->m_actions = m_actions;
@@ -351,7 +358,7 @@ namespace gloox
 
           std::string m_node;
           std::string m_sessionid;
-          DataForm* m_form;
+          AdhocPlugin* m_plugin;
           Action m_action;
           Status m_status;
           int m_actions;
@@ -403,7 +410,7 @@ namespace gloox
        * Use this function to respond to an execution request submitted by means
        * of AdhocCommandProvider::handleAdhocCommand().
        * It is recommended to use
-       * Command( const std::string&, const std::string&, Status, DataForm* )
+       * Command( const std::string&, const std::string&, Status, AdhocPlugin* )
        * to construct the @c command object.
        * Optionally, an Error object can be included. In that case the IQ sent is of type @c error.
        * @param remote The requester's JID.
