@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2014 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2015 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -22,26 +22,26 @@ namespace gloox
 {
 
   DataForm::DataForm( FormType type, const StringList& instructions, const std::string& title )
-    : StanzaExtension( ExtDataForm ),
+    : AdhocPlugin( ExtDataForm ),
       m_type( type ), m_instructions( instructions ), m_title( title ), m_reported( 0 )
   {
   }
 
   DataForm::DataForm( FormType type, const std::string& title )
-    : StanzaExtension( ExtDataForm ),
+    : AdhocPlugin( ExtDataForm ),
       m_type( type ), m_title( title ), m_reported( 0 )
   {
   }
 
   DataForm::DataForm( const Tag* tag )
-    : StanzaExtension( ExtDataForm ),
+    : AdhocPlugin( ExtDataForm ),
       m_type( TypeInvalid ), m_reported( 0 )
   {
     parse( tag );
   }
 
   DataForm::DataForm( const DataForm& form )
-    : StanzaExtension( ExtDataForm ), DataFormFieldContainer( form ),
+    : AdhocPlugin( ExtDataForm ), DataFormFieldContainer( form ),
       m_type( form.m_type ), m_instructions( form.m_instructions ),
       m_title( form.m_title ), m_reported( form.m_reported ? new DataFormReported( form.m_reported->tag() ) : 0 )
   {
