@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2014 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2015 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,7 +30,7 @@ namespace gloox
 
   bool OpenSSLClient::setType()
   {
-    m_ctx = SSL_CTX_new( SSLv23_client_method() ); // FIXME: use TLSv1_client_method() as soon as OpenSSL/gtalk combo is fixed!
+    m_ctx = SSL_CTX_new( TLSv1_client_method() );
     if( !m_ctx )
       return false;
 
